"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSourcingConfig = void 0;
const gatsby_graphql_source_toolkit_1 = require("gatsby-graphql-source-toolkit");
const drupal_feeds_1 = require("./drupal-feeds");
const createSourcingConfig = (gatsbyApi, execute, 
// eslint-disable-next-line @typescript-eslint/no-unused-vars
customFragments) => __awaiter(void 0, void 0, void 0, function* () {
    const schema = yield (0, gatsby_graphql_source_toolkit_1.loadSchema)(execute);
    const drupalFeeds = yield (0, drupal_feeds_1.drupalFeeds)(execute);
    const isTranslatable = (item) => drupalFeeds.filter((feed) => feed.typeName === (item === null || item === void 0 ? void 0 : item.remoteTypeName) && feed.translatable).length > 0;
    // Instruct gatsby-graphql-source-toolkit how to fetch content from Drupal.
    // The LIST_ queries are used to fetch the content when there is no cache. The
    // NODE_ queries are used to fetch incremental updates.
    // More details in https://github.com/gatsbyjs/gatsby-graphql-toolkit#readme
    const gatsbyNodeTypes = [];
    for (const feed of drupalFeeds) {
        gatsbyNodeTypes.push({
            remoteTypeName: feed.typeName,
            queries: `
        query LIST_${feed.typeName} {
          ${feed.listFieldName}(
            limit: $limit
            offset: $offset
          ) {
            __typename
            ${feed.translatable
                ? `translations {
                     ..._${feed.typeName}Id_
                   }`
                : `..._${feed.typeName}Id_`}
          }
        }
        query NODE_${feed.typeName} {
          ${feed.singleFieldName}(id: $id) {
            ..._${feed.typeName}Id_
          }
        }
        fragment _${feed.typeName}Id_ on ${feed.typeName} {
          __typename
          id
        }
      `,
        });
    }
    const fragments = yield (0, gatsby_graphql_source_toolkit_1.generateDefaultFragments)({
        schema,
        gatsbyNodeTypes,
    });
    const documents = (0, gatsby_graphql_source_toolkit_1.compileNodeQueries)({
        schema,
        gatsbyNodeTypes,
        customFragments: fragments,
    });
    const LimitOffsetTranslatable = Object.assign(Object.assign({}, gatsby_graphql_source_toolkit_1.LimitOffset), { getItems: (pageOrResult) => {
            return pageOrResult
                .map((node) => (isTranslatable(node) ? node.translations : [node]))
                .reduce((acc, val) => acc.concat(val), []);
        } });
    return {
        gatsbyApi,
        schema,
        execute,
        paginationAdapters: [LimitOffsetTranslatable],
        gatsbyTypePrefix: 'Drupal',
        gatsbyNodeDefs: (0, gatsby_graphql_source_toolkit_1.buildNodeDefinitions)({ gatsbyNodeTypes, documents }),
    };
});
exports.createSourcingConfig = createSourcingConfig;
